@@ -3,6 +3,7 @@ Custom exceptions for ConfigurationPanda.
 
 """
 
+
 class ConfigurationPandaError(Exception):
     """
     Base exception class for ConfigurationPanda Errors.
@@ -19,6 +20,15 @@ class DuplicateJSONFile(ConfigurationPandaError):
     pass
 
 
+class MalformedJSONFile(ConfigurationPandaError):
+    """
+    Error to raise when an attempt is made to load a configuration
+    file contained malformed JSON.
+
+    """
+    pass
+
+
 class ExistingEnvironmentVariable(ConfigurationPandaError):
     """
     Error to raise when an existing environment variable prevents a
@@ -34,3 +44,5 @@ class InvalidParameter(ConfigurationPandaError):
     input provided by the client.
 
     """
+    pass
+
